﻿#region License Information
/* HeuristicLab
 * Copyright (C) 2002-2015 Heuristic and Evolutionary Algorithms Laboratory (HEAL)
 *
 * This file is part of HeuristicLab.
 *
 * HeuristicLab is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * HeuristicLab is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HeuristicLab. If not, see <http://www.gnu.org/licenses/>.
 */
#endregion

using HeuristicLab.Common;
using HeuristicLab.Core;
using HeuristicLab.Data;
using HeuristicLab.Encodings.RealVectorEncoding;
using HeuristicLab.Parameters;
using HeuristicLab.Persistence.Default.CompositeSerializers.Storable;
using System.Linq;

namespace HeuristicLab.BioBoost.SolutionCreation {

  [StorableClass]
  public class ConstantValueRealVectorCreator : RealVectorCreator {

    public IValueLookupParameter<DoubleValue> ValueParameter {
      get { return (IValueLookupParameter<DoubleValue>) Parameters["Value"]; }
    }

    public double Value {
      get { return ValueParameter.ActualValue.Value; }
      set { ValueParameter.Value = new DoubleValue(value); }
    }

      #region Construction & Cloning
    [StorableConstructor]
    protected ConstantValueRealVectorCreator(bool isDeserializing) : base(isDeserializing) {}
    protected ConstantValueRealVectorCreator(ConstantValueRealVectorCreator orig, Cloner cloner) : base(orig, cloner) {}
    public ConstantValueRealVectorCreator() {
      Parameters.Add(new ValueLookupParameter<DoubleValue>("Value", "The constant value to be replicated.", new DoubleValue(1)));
      BoundsParameter.Value = new DoubleMatrix(new double[,] {{1, 1}});
    }
    public override IDeepCloneable Clone(Cloner cloner) {
      return new ConstantValueRealVectorCreator(this, cloner);
    }
    #endregion

    protected override RealVector Create(IRandom random, IntValue length, DoubleMatrix bounds) {
      return new RealVector(Enumerable.Repeat(Value, length.Value).ToArray());
    }

  }
}
